# frozen_string_literal: true

module Hermes
  class Operation
    include Hermes::Concerns::CommonFieldsConcern

    field :name, type: String
    field :code, type: String

    include Slugable
    sluggify :code

    belongs_to :lessor, class_name: 'Hermes::Lessor', index: true

    validates :name, presence: true
    owner_field :user_id

    common_indexes :name, :code, :slug

    before_save :default_code_value, :set_slug_if_possible, :ensure_code_uniqueness

    private

    def default_code_value
      self.code = 'ALSOP' if code.blank?
    end

    def ensure_code_uniqueness
      self.code = slug != code.downcase ? slug.upcase : code.upcase
    end
  end
end