require 'rails_helper'

RSpec.describe Hermes::BoClient::Mappings::ApplicantReverseMap, type: :helper do
  describe 'work_contract_type mapping' do 
    [
      {sne_code: 'SAL', applicant_code: 'CDIP', cdd_interim: "true" },
      {sne_code: 'SAL', applicant_code: 'CDI'},
      {sne_code: 'AGE', applicant_code: 'AGP'},
      {sne_code: 'CHO', applicant_code: 'CHO'},
      {sne_code: 'ETA', applicant_code: 'APP', siret: 'siret'},
      {sne_code: 'ETA', applicant_code: 'ETU'},
      {sne_code: 'ASS', applicant_code: 'ASS'},
      {sne_code: 'AGH', applicant_code: 'AGH'},
      {sne_code: 'ACT', applicant_code: 'ACT'},
      {sne_code: 'IND', applicant_code: 'IND'},
      {sne_code: 'RET', applicant_code: 'RET'},
      {sne_code: 'AUTS', applicant_code: 'AUT'},
    ].each do |mapping|
      it "works for #{mapping[:sne_code]}" do
        expect(Hermes::BoClient::Mappings::ApplicantReverseMap.new(nil, nil).typeContratTravail_v4_map(mapping[:sne_code], mapping[:cdd_interim], mapping[:siret])).to eq(mapping[:applicant_code])
      end 
    end 
  end 

  describe 'homephone' do
    let(:unique_number) { '1110121047572GDPUB' }
    let(:file_path) { Hermes::Engine.root.join('spec', 'xml_bouchon', 'v4', "#{unique_number}.xml") }
    let(:xml_string) { File.read(file_path) }
    let(:parsed_xml) { Hash.from_xml(xml_string.delete("\n")) }
  
    subject { described_class.new(parsed_xml, true).build_applicant[:homephone] }
  
    describe 'default behavior' do
      it 'extracts homephone from xml' do
        expect(subject).to eq('0666666666')
      end
    end
  
    shared_examples 'handles blank homephone' do |value, expected_result|
      before do
        parsed_xml["interfaceNuu"]["demande"]["demandeLogement"]["personnePhysique"]["demandeur"]['telDomicilePro'] = value
      end
  
      it "returns #{expected_result.inspect}" do
        expect(subject).to eq(expected_result)
      end
    end
  
    context 'when demandeur is null' do
      it_behaves_like 'handles blank homephone', nil, nil
    end
  
    context 'when empty' do
      it_behaves_like 'handles blank homephone', '', ''
    end
  end
end